@@ -47,7 +47,7 @@ QString ImapStreamParser::readUtf8String()
 QByteArray ImapStreamParser::readString()
 {
     QByteArray result;
-    if (!waitForMoreData(m_data.length() == 0)) {
+    if (!waitForMoreData(m_data.isEmpty())) {
         throw ImapParserException("Unable to read more data");
     }
     stripLeadingSpaces();
@@ -77,19 +77,18 @@ bool ImapStreamParser::hasString()
     stripLeadingSpaces();
     int pos = m_position;
     m_position = savedPos;
-    if (m_data.at(pos) == '{') {
+    const char dataChar = m_data.at(pos);
+    if (dataChar == '{') {
         return true; //literal string
-    }
-    if (m_data.at(pos) == '"') {
+    } else if (dataChar == '"') {
         return true; //quoted string
-    }
-    if (m_data.at(pos) != ' ' &&
-            m_data.at(pos) != '(' &&
-            m_data.at(pos) != ')' &&
-            m_data.at(pos) != '[' &&
-            m_data.at(pos) != ']' &&
-            m_data.at(pos) != '\n' &&
-            m_data.at(pos) != '\r') {
+    } else if (dataChar != ' ' &&
+            dataChar != '(' &&
+            dataChar != ')' &&
+            dataChar != '[' &&
+            dataChar != ']' &&
+            dataChar != '\n' &&
+            dataChar != '\r') {
         return true;  //unquoted string
     }
 
